@@ -53,6 +53,10 @@ MODTEST_OVERRIDE12=/lib/modules/$MODTEST_UNAME/modules.symbols
 MODTEST_OVERRIDE_WITH12=tests/tmp/modules.symbols
 export MODTEST_OVERRIDE12 MODTEST_OVERRIDE_WITH12
 
+MODTEST_OVERRIDE13=/lib/modules/$MODTEST_UNAME/modules.ieee1394map
+MODTEST_OVERRIDE_WITH13=tests/tmp/modules.ieee1394map
+export MODTEST_OVERRIDE13 MODTEST_OVERRIDE_WITH13
+
 # Expect no normal output.
 [ "`depmod 2>&1`" = "" ]
 
